@@ -54,7 +54,7 @@ class DatasetFactory():
             NotImplementedError: Needs to be implemented by subclasses.
         """
 
-        raise NotImplementedError()
+        raise NotImplementedError('Needs to be implemented by subclasses.')
 
     def create_catalogue_ml(self, df: pd.DataFrame) -> pd.DataFrame:
         """Creates the dataframe for machine learning models.
@@ -295,7 +295,7 @@ class DatasetFactoryWildMe(DatasetFactory):
 
 
 class AAUZebraFishID(DatasetFactory):
-    download = downloads.aau_zebrafish_id
+    download = downloads.AAUZebraFish
     metadata = metadata['AAUZebraFishID']
     
     def create_catalogue(self) -> pd.DataFrame:
@@ -342,7 +342,7 @@ class AAUZebraFishID(DatasetFactory):
 
 
 class AerialCattle2017(DatasetFactory):
-    download = downloads.aerial_cattle_2017
+    download = downloads.AerialCattle2017
     metadata = metadata['AerialCattle2017']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -361,7 +361,7 @@ class AerialCattle2017(DatasetFactory):
 
 
 class ATRW(DatasetFactory):
-    download = downloads.atrw
+    download = downloads.ATRW
     metadata = metadata['ATRW']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -439,7 +439,7 @@ class ATRW(DatasetFactory):
 
 
 class BelugaID(DatasetFactoryWildMe):
-    download = downloads.beluga_id
+    download = downloads.BelugaID
     metadata = metadata['BelugaID']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -448,7 +448,7 @@ class BelugaID(DatasetFactoryWildMe):
 
 
 class BirdIndividualID(DatasetFactory):
-    download = downloads.bird_individual_id
+    download = downloads.BirdIndividualID
     metadata = metadata['BirdIndividualID']
     prefix1 = 'Original_pictures'
     prefix2 = 'IndividualID'
@@ -500,13 +500,13 @@ class BirdIndividualID(DatasetFactory):
 
 
 class BirdIndividualIDSegmented(BirdIndividualID):
-    download = downloads.segmented
+    download = downloads.Segmented
     prefix1 = 'Cropped_pictures'
     prefix2 = 'IndividuaID'
 
 
 class CTai(DatasetFactory):
-    download = downloads.c_tai
+    download = downloads.CTai
     metadata = metadata['CTai']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -548,7 +548,7 @@ class CTai(DatasetFactory):
 
 
 class CZoo(DatasetFactory):
-    download = downloads.c_zoo
+    download = downloads.CZoo
     metadata = metadata['CZoo']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -575,7 +575,7 @@ class CZoo(DatasetFactory):
 
 
 class Cows2021(DatasetFactory):
-    download = downloads.cows_2021
+    download = downloads.Cows2021
     metadata = metadata['Cows2021']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -610,7 +610,7 @@ class Cows2021(DatasetFactory):
 
 
 class Drosophila(DatasetFactory):
-    download = downloads.drosophila
+    download = downloads.Drosophila
     metadata = metadata['Drosophila']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -639,7 +639,7 @@ class Drosophila(DatasetFactory):
 
 
 class FriesianCattle2015(DatasetFactory):
-    download = downloads.friesian_cattle_2015
+    download = downloads.FriesianCattle2015
     metadata = metadata['FriesianCattle2015']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -662,7 +662,7 @@ class FriesianCattle2015(DatasetFactory):
 
 
 class FriesianCattle2017(DatasetFactory):
-    download = downloads.friesian_cattle_2017
+    download = downloads.FriesianCattle2017
     metadata = metadata['FriesianCattle2017']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -680,7 +680,7 @@ class FriesianCattle2017(DatasetFactory):
 
 
 class GiraffeZebraID(DatasetFactoryWildMe):
-    download = downloads.giraffe_zebra_id
+    download = downloads.GiraffeZebraID
     metadata = metadata['GiraffeZebraID']
     
     def create_catalogue(self) -> pd.DataFrame:
@@ -688,7 +688,7 @@ class GiraffeZebraID(DatasetFactoryWildMe):
 
 
 class Giraffes(DatasetFactory):
-    download = downloads.giraffes
+    download = downloads.Giraffes
     metadata = metadata['Giraffes']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -711,7 +711,7 @@ class Giraffes(DatasetFactory):
 
 
 class HappyWhale(DatasetFactory):
-    download = downloads.happy_whale
+    download = downloads.HappyWhale
     metadata = metadata['HappyWhale']
     
     def create_catalogue(self) -> pd.DataFrame:
@@ -754,7 +754,7 @@ class HappyWhale(DatasetFactory):
 
 
 class HumpbackWhaleID(DatasetFactory):
-    download = downloads.humpback_whale
+    download = downloads.HumpbackWhaleID
     metadata = metadata['HumpbackWhaleID']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -787,7 +787,7 @@ class HumpbackWhaleID(DatasetFactory):
 
 
 class HyenaID2022(DatasetFactoryWildMe):
-    download = downloads.hyena_id_2022
+    download = downloads.HyenaID2022
     metadata = metadata['HyenaID2022']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -795,7 +795,7 @@ class HyenaID2022(DatasetFactoryWildMe):
 
 
 class IPanda50(DatasetFactory):
-    download = downloads.ipanda_50
+    download = downloads.IPanda50
     metadata = metadata['IPanda50']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -833,7 +833,7 @@ class IPanda50(DatasetFactory):
 
 
 class LeopardID2022(DatasetFactoryWildMe):
-    download = downloads.leopard_id_2022
+    download = downloads.LeopardID2022
     metadata = metadata['LeopardID2022']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -841,7 +841,7 @@ class LeopardID2022(DatasetFactoryWildMe):
 
 
 class LionData(DatasetFactory):
-    download = downloads.lion_data
+    download = downloads.LionData
     metadata = metadata['LionData']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -859,7 +859,7 @@ class LionData(DatasetFactory):
 
 
 class MacaqueFaces(DatasetFactory):
-    download = downloads.macaque_faces
+    download = downloads.MacaqueFaces
     metadata = metadata['MacaqueFaces']
     
     def create_catalogue(self) -> pd.DataFrame:
@@ -879,7 +879,7 @@ class MacaqueFaces(DatasetFactory):
 
 
 class NDD20(DatasetFactory):
-    download = downloads.ndd20
+    download = downloads.NDD20
     metadata = metadata['NDD20']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -947,7 +947,7 @@ class NDD20(DatasetFactory):
 
 
 class NOAARightWhale(DatasetFactory):
-    download = downloads.noaa_right_whale
+    download = downloads.NOAARightWhale
     metadata = metadata['NOAARightWhale']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -974,7 +974,7 @@ class NOAARightWhale(DatasetFactory):
 
 
 class NyalaData(DatasetFactory):
-    download = downloads.nyala_data
+    download = downloads.NyalaData
     metadata = metadata['NyalaData']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -999,7 +999,7 @@ class NyalaData(DatasetFactory):
 
 
 class OpenCows2020(DatasetFactory):
-    download = downloads.open_cows_2020
+    download = downloads.OpenCows2020
     metadata = metadata['OpenCows2020']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -1026,7 +1026,7 @@ class OpenCows2020(DatasetFactory):
 
 
 class SealID(DatasetFactory):
-    download = downloads.seal_id
+    download = downloads.SealID
     metadata = metadata['SealID']
     prefix = 'source_'
 
@@ -1046,12 +1046,12 @@ class SealID(DatasetFactory):
 
 
 class SealIDSegmented(SealID):
-    download = downloads.segmented
+    download = downloads.Segmented
     prefix = 'segmented_'
 
 
 class SeaTurtleID(DatasetFactory):
-    download = downloads.sea_turtle_id
+    download = downloads.SeaTurtleID
     metadata = metadata['SeaTurtleID']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -1077,7 +1077,7 @@ class SeaTurtleID(DatasetFactory):
 
 
 class SeaTurtleIDHeads(DatasetFactory):
-    download = downloads.sea_turtle_id_heads
+    download = downloads.SeaTurtleIDHeads
     metadata = metadata['SeaTurtleIDHeads']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -1103,7 +1103,7 @@ class SeaTurtleIDHeads(DatasetFactory):
 
 
 class SMALST(DatasetFactory):
-    download = downloads.smalst
+    download = downloads.SMALST
     metadata = metadata['SMALST']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -1132,7 +1132,7 @@ class SMALST(DatasetFactory):
 
 
 class StripeSpotter(DatasetFactory):
-    download = downloads.stripe_spotter
+    download = downloads.StripeSpotter
     metadata = metadata['StripeSpotter']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -1162,7 +1162,7 @@ class StripeSpotter(DatasetFactory):
 
 
 class WhaleSharkID(DatasetFactoryWildMe):
-    download = downloads.whale_shark_id
+    download = downloads.WhaleSharkID
     metadata = metadata['WhaleSharkID']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -1170,7 +1170,7 @@ class WhaleSharkID(DatasetFactoryWildMe):
 
 
 class WNIGiraffes(DatasetFactory):
-    download = downloads.wni_giraffes
+    download = downloads.WNIGiraffes
     metadata = metadata['WNIGiraffes']
 
     def create_catalogue(self) -> pd.DataFrame:
@@ -1208,7 +1208,7 @@ class WNIGiraffes(DatasetFactory):
 
 
 class ZindiTurtleRecall(DatasetFactory):
-    download = downloads.zindi_turtle_recall
+    download = downloads.ZindiTurtleRecall
     metadata = metadata['ZindiTurtleRecall']
 
     def create_catalogue(self) -> pd.DataFrame:
